# mypy-boto3-glue

[![PyPI - mypy-boto3-glue](https://img.shields.io/pypi/v/mypy-boto3-glue.svg?color=blue)](https://pypi.org/project/mypy-boto3-glue)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-glue.svg?color=blue)](https://pypi.org/project/mypy-boto3-glue)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)

Type annotations for
[boto3.Glue 1.14.53](https://boto3.amazonaws.com/v1/documentation/api/1.14.53/reference/services/glue.html#Glue) service
compatible with [mypy](https://github.com/python/mypy), [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/) and other tools.

Generated by [mypy-boto3-buider 2.4.0](https://github.com/vemel/mypy_boto3_builder).

More information can be found on [boto3-stubs](https://pypi.org/project/boto3-stubs/) page.

## How to install

Make sure you have [mypy](https://github.com/python/mypy) installed and activated in your IDE.

Install `boto3-stubs` for `Glue` service.

```bash
python -m pip install boto3-stubs[glue]
```

## How to use

### Client annotations

`GlueClient` provides annotations for `boto3.client("glue")`.

```python
import boto3

from mypy_boto3_glue import GlueClient
from mypy_boto3_glue.paginator import (
    GetClassifiersPaginator,
    GetConnectionsPaginator,
    GetCrawlerMetricsPaginator,
    GetCrawlersPaginator,
    GetDatabasesPaginator,
    GetDevEndpointsPaginator,
    GetJobRunsPaginator,
    GetJobsPaginator,
    GetPartitionsPaginator,
    GetSecurityConfigurationsPaginator,
    GetTablesPaginator,
    GetTableVersionsPaginator,
    GetTriggersPaginator,
    GetUserDefinedFunctionsPaginator,
)
from mypy_boto3_glue.type_defs import ActionTypeDef, ...

client: GlueClient = boto3.client("glue")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: GlueClient = session.client("glue")
```

### Paginators annotations

`mypy_boto3_glue.paginator` module contains type annotations for all paginators.

```python

client: GlueClient = boto3.client("glue")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
get_classifiers_paginator: GetClassifiersPaginator = client.get_paginator("get_classifiers")
get_connections_paginator: GetConnectionsPaginator = client.get_paginator("get_connections")
get_crawler_metrics_paginator: GetCrawlerMetricsPaginator = client.get_paginator("get_crawler_metrics")
get_crawlers_paginator: GetCrawlersPaginator = client.get_paginator("get_crawlers")
get_databases_paginator: GetDatabasesPaginator = client.get_paginator("get_databases")
get_dev_endpoints_paginator: GetDevEndpointsPaginator = client.get_paginator("get_dev_endpoints")
get_job_runs_paginator: GetJobRunsPaginator = client.get_paginator("get_job_runs")
get_jobs_paginator: GetJobsPaginator = client.get_paginator("get_jobs")
get_partitions_paginator: GetPartitionsPaginator = client.get_paginator("get_partitions")
get_security_configurations_paginator: GetSecurityConfigurationsPaginator = client.get_paginator("get_security_configurations")
get_table_versions_paginator: GetTableVersionsPaginator = client.get_paginator("get_table_versions")
get_tables_paginator: GetTablesPaginator = client.get_paginator("get_tables")
get_triggers_paginator: GetTriggersPaginator = client.get_paginator("get_triggers")
get_user_defined_functions_paginator: GetUserDefinedFunctionsPaginator = client.get_paginator("get_user_defined_functions")
```







### Typed dictionations

`mypy_boto3_glue.type_defs` module contains structures and shapes assembled
to typed dictionaries for additional type checking.

```python

def get_structure() -> ActionTypeDef:
    return {
      ...
    }
```


## Dynamic type annotations

`mypy_boto3` command generates `boto3.client/resource` type annotations for
`mypy_boto3_glue` and other installed services.

```bash
# Run this command after you add or remove service packages
python -m mypy_boto3
```

Generated type annotations provide overloads for `boto3.client` and `boto3.resource`,
`boto3.Session.client` and `boto3.Session.resource` functions,
so explicit type annotations are not needed.

- `mypy` supports function overloads as expected
- `PyCharm` also supports function overloads, but consumes a lot of RAM, use carefully if you have many services installed
- `VSCode` does not currently support function overloads, use explicit type annotations

```python

# Type is discovered correctly by mypy and PyCharm
# VSCode still needs explicit type annotations
client = boto3.client("glue")

session_client = boto3.Session().client("glue")
```
